@@ -48,7 +48,7 @@ impl PlatformApi for QuartzApi {
     fn get_active_window(&self) -> Result<u64> {
         env::var("WINDOWID")
             .context(
-                r#"Cannot determine the active window. 
+                r#"Cannot determine the active window.
  - Please set either env variable `TERM_PROGRAM` e.g. `TERM_PROGRAM=alacritty t-rec`
  - Or set `WINDOWID` see also `t-rec -l` to list all windows with their id
  - If you're using alacritty: https://github.com/sassman/t-rec-rs/issues/44#issuecomment-830630348
@@ -59,7 +59,7 @@ impl PlatformApi for QuartzApi {
     }
 }
 
-#[cfg(feature = "test_against_real_display")]
+#[cfg(feature = "e2e_tests")]
 #[cfg(test)]
 mod test {
     use super::*;
